diff inst/import_ufl_LinearForm.m @ 136:c445cdf36fb1

Fix new naming convention for the generation of the problem from .ufl file.
author gedeone-octave <marcovass89@hotmail.it>
date Fri, 06 Sep 2013 13:42:20 +0200
parents 547763139e1a
children f2193e825ad7
line wrap: on
line diff
--- a/inst/import_ufl_LinearForm.m	Fri Sep 06 13:30:10 2013 +0200
+++ b/inst/import_ufl_LinearForm.m	Fri Sep 06 13:42:20 2013 +0200
@@ -15,21 +15,18 @@
 
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
 ## This function take as input the name of the .ufl file where 
 ## the Variational Problem is defined.
 ## @example
 ## 
 ## @end example
 ## @seealso{} 
 ## @end deftypefn
 
-function fem_create_lhs (var_prob)
+function import_ufl_LinearForm (var_prob)
 
   if nargin != 1
-    error ("fem_create_lhs: wrong number of input parameters.");
+    error ("import_ufl_LinearForm: wrong number of input parameters.");
   elseif ! ischar (var_prob)
-    error ("fem_create_lhs: first argument is not a valid string");
+    error ("import_ufl_LinearForm: first argument is not a valid string");
   endif
 
   n = length (mfilename ("fullpath")) - length (mfilename());
@@ -15,21 +15,18 @@
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
-## This function take as input the name of the .ufl file where 
-## the Variational Problem is defined.
-## @example
-## 
-## @end example
-## @seealso{} 
+## @deftypefn {Function File} {} = import_ufl_LinearForm (myproblem)
+## This function takes as input the name of the .ufl file where 
+## the LinearForm is defined and import it inside Octave
+## @seealso{import_ufl_Problem, FunctionSpace, BilinearForm, LinearForm} 
 ## @end deftypefn
 